## 5/20 Follow Dart file conventions

### [x] 0/10 points: Provide a valid `pubspec.yaml`

<details>
<summary>
Sdk-constraint doesn't allow future stable dart 2.x releases
</summary>

`pubspec.yaml:8:8`

```
  ╷
8 │   sdk: ">=2.12.0-0 <2.12.0"
  │        ^^^^^^^^^^^^^^^^^^^^
  ╵
```

</details>
<details>
<summary>
The package description is too short.
</summary>

Add more detail to the `description` field of `pubspec.yaml`. Use 60 to 180 characters to describe the package, what it does, and its target use case.
</details>

### [*] 5/5 points: Provide a valid `README.md`


### [x] 0/5 points: Provide a valid `CHANGELOG.md`

<details>
<summary>
No `CHANGELOG.md` found.
</summary>

Changelog entries help developers follow the progress of your package. See the [example](https://raw.githubusercontent.com/dart-lang/stagehand/master/templates/package-simple/CHANGELOG.md) generated by `stagehand`.
</details>

## 0/10 Provide documentation

### [x] 0/10 points: Package has an example

<details>
<summary>
No example found.
</summary>

See [package layout](https://dart.dev/tools/pub/package-layout#examples) guidelines on how to add an example.
</details>

## 20/20 Support multiple platforms

### [*] 20/20 points: Supports 2 of 2 possible platforms (**native**, **js**)


## 20/30 Pass static analysis

### [~] 20/30 points: code has no errors, warnings, lints, or formatting issues

<details>
<summary>
INFO: The library 'package:retry/retry.dart' is legacy, and should not be imported into a null safe library.
</summary>

`lib/_dummy_pkg.dart:1:8`

```
  ╷
1 │ import 'package:retry/retry.dart';
  │        ^^^^^^^^^^^^^^^^^^^^^^^^^^
  ╵
```

To reproduce make sure you are using [pedantic](https://pub.dev/packages/pedantic#using-the-lints) and run `dartanalyzer lib/_dummy_pkg.dart`
</details>

## 0/20 Support up-to-date dependencies

### [x] 0/10 points: All of the package dependencies are supported in the latest version

|Package|Constraint|Compatible|Latest|
|:-|:-|:-|:-|
|[`retry`]|`^2.0.0`|2.0.0|**3.0.1**|

To reproduce run `pub outdated --no-dev-dependencies --up-to-date --no-dependency-overrides`.

[`retry`]: https://pub.dev/packages/retry

<details>
<summary>
The constraint `^2.0.0` on retry does not support the stable version `3.0.0`.
</summary>

Try running `dart pub upgrade --major-versions retry` to update the constraint.
</details>

### [x] 0/10 points: Package supports latest stable Dart and Flutter SDKs

* Found no Flutter in your PATH. Could not determine the current Flutter version.

## 0/0 Support sound null-safety

### [x] 0/0 points: Package declares support for null-safety, but there are issues.

Packages with full null-safety support will be awarded additional points in a planned future revision of the pub.dev points model.

<details>
<summary>
Package is not null safe
</summary>

Because:
* `_dummy_pkg` that depends on:
* `retry` that doesn't opt in to null safety
</details>
<details>
<summary>
For more information
</summary>

Try running `pub outdated --mode=null-safety`.
Be sure to read the [migration guide](https://dart.dev/null-safety/migration-guide).
</details>